/****************************************************************************
** $Id$
**
** Definition of QSimpleInputContext class
**
** Copyright (C) 2004 immodule for Qt Project.  All rights reserved.
**
** This file is written to contribute to Trolltech AS under their own
** licence. You may use this file under your Qt license. Following
** description is copied from their original file headers. Contact
** immodule-qt@freedesktop.org if any conditions of this licensing are
** not clear to you.
**
****************************************************************************/

/****************************************************************************
**
** Copyright (C) 1992-2004 Trolltech AS. All rights reserved.
**
** This file is part of the input method module of the Qt Toolkit.
**
** Licensees holding valid Qt Preview licenses may use this file in
** accordance with the Qt Preview License Agreement provided with the
** Software.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
** information about Qt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#ifndef QSIMPLEINPUT_CONTEXT_H
#define QSIMPLEINPUT_CONTEXT_H

#include <qinputcontext.h>
#include <qnamespace.h>

#define QT_KEYSEQUENCE_MAX_LEN 6
#define UNITIZE(qkey) (0x02000000|qkey)

struct QComposeTableElement {
    uint keys[QT_KEYSEQUENCE_MAX_LEN];
    uint value;
};

struct QComposeTable {
    const QComposeTableElement *data;
    uint size;
};


class QSimpleInputContext : public QInputContext {
    Q_OBJECT
public:
    QSimpleInputContext();
    ~QSimpleInputContext();

    virtual QString identifierName();
    virtual QString language();

    virtual bool filterEvent( const QEvent *event );
    virtual void reset();
    virtual void setFocus();
    virtual void unsetFocus();
    virtual void setMicroFocus( int x, int y, int w, int h, QFont *f = 0 );
    virtual void mouseHandler( int x, QEvent::Type type,
			       Qt::ButtonState button, Qt::ButtonState state );

protected:
    bool isIgnoreKeys(int keyval );
    bool isComposingKeys( int keyval );
    bool checkComposeTable( uint composeBuffer[], const QComposeTable *composeTable );
    void commitChar( uint c );

    void clearComposeBuffer(void);

protected:
    uint composeBuffer[QT_KEYSEQUENCE_MAX_LEN + 1];
    static const QComposeTable defaultComposeTable;
};

#endif // QSIMPLEINPUT_CONTEXT_H
